==> haskell-cheapskate-0.1.0.4-19-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cheapskate/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.0.4
id: cheapskate-0.1.0.4-c2e9c000038a7a74d6b3323df2bd8de6
key: cheap_1yivIgsZUUnAmg2ZWLLmDt
license: BSD3
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Parse Cheapskate.Types Cheapskate.Html
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/cheapskate-0.1.0.4
hs-libraries: HScheapskate-0.1.0.4-1yivIgsZUUnAmg2ZWLLmDt
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    uniplate-1.6.12-474087ddfa30ffe8f83d021d3c4c23e6
    xss-sanitize-0.3.5.6-f78b5b03aa1efe6d65b9961065a15c78
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.0.4-20-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cheapskate/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cheapskate
version: 0.1.0.4
id: cheapskate-0.1.0.4-99dbe614d2e414c63e0cb14960ec401b
key: cheap_DbWTwUmY0bmHbSpxJlP7rw
license: BSD3
copyright: (C) 2012-2013 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: http://github.com/jgm/cheapskate
synopsis: Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.
    .
    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Cheapskate Cheapskate.Parse Cheapskate.Types Cheapskate.Html
hidden-modules: Cheapskate.Util Cheapskate.Inlines
                Cheapskate.ParserCombinators Paths_cheapskate
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/cheapskate-0.1.0.4
hs-libraries: HScheapskate-0.1.0.4-DbWTwUmY0bmHbSpxJlP7rw
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    uniplate-1.6.12-474087ddfa30ffe8f83d021d3c4c23e6
    xss-sanitize-0.3.5.6-f78b5b03aa1efe6d65b9961065a15c78
haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html: /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
